@@ -34,9 +34,20 @@ Find rules at:	https://www.arrl.org/rtty-roundup
 import datetime
 
 from pathlib import Path
-from lib.ham_utility import get_logged_band
-from lib.plugin_common import gen_adif, get_points, online_score_xml
-from lib.version import __version__
+
+# from lib.ham_utility import get_logged_band
+# from lib.plugin_common import gen_adif, get_points, online_score_xml
+# from lib.version import __version__
+
+# Import path may change depending on if it's dev or production.
+try:
+    from lib.ham_utility import get_logged_band
+    from lib.plugin_common import gen_adif, get_points, online_score_xml
+    from lib.version import __version__
+except (ImportError, ModuleNotFoundError):
+    from renfield.lib.ham_utility import get_logged_band
+    from renfield.lib.plugin_common import gen_adif, get_points, online_score_xml
+    from renfield.lib.version import __version__
 
 name = "ARRL RTTY Roundup"
 mode = "RTTY"  # CW SSB BOTH RTTY
@@ -303,10 +314,7 @@ def cabrillo(self, file_encoding):
                     file_encoding,
                 )
             output_cabrillo_line("END-OF-LOG:", "\r\n", file_descriptor, file_encoding)
-        self.show_message_box(f"Cabrillo saved to: {filename}")
-    except IOError as exception:
-        print("cabrillo: IO error: %s, writing to %s", exception, filename)
-        self.show_message_box(f"Error saving Cabrillo: {exception} {filename}")
+    except IOError:
         return
 
 
